ramsvm = function(x, y, gamma=0.5, weight=NULL, lambda, kernel=c("linear","polynomial", "gaussian"), kparam=1, large=FALSE, epsilon = NULL, warm=NULL, nb.core=NULL)
{
	if (!is.matrix(x)) stop("The covariates should be a matrix.")	
	if (is.na(sum(x)) | is.nan(sum(x))) stop("There should be no NA/NaN in the covariates.")	

	if (length(y)!=nrow(x)) {stop("The dimension of covariates should match the length of the label.")}

	k = length(summary(as.factor(y)))
	if (k==1) {stop("There must be at least two classes.")}
	
	if (is.null(epsilon)) {epsilon = 0.0001*nrow(x)*k}
	if (is.na(epsilon) | is.nan(epsilon)) stop("Epsilon should not be NA/NaN.")
	if (!is.numeric(epsilon)) {stop("Epsilon should be numeric.")}
	if (epsilon<=0) {stop("Epsilon should be strictly positive.")}
	if (length(as.vector(epsilon))>1) {stop("Epsilon should be a scalar.")}
		
	if (is.null(weight)) {weight = rep(1,nrow(x))}

	if (!is.numeric(weight)) {stop("The weight vector should be numeric.")}
	if (is.na(sum(weight)) | is.nan(sum(weight))) stop("There should be no NA/NaN in the weight vector.")
	if (min(weight)<0) {stop("The weight vector should be non-negative.")}
	if (length(weight)!=nrow(x)) {stop("The length of the weight should agree with the number of observations.")}
	if (!is.null(warm)) {
		if (sum(1-(dim(warm)==c(nrow(x),k)))) {stop("The dimension of the warm start matrix is incorrect.")}
					}

if (any(lambda <= 0))  { stop("All lambdas must be positive.") }

	kernel = match.arg(kernel)
	this.call = match.call()

	fit = switch(kernel, 
	linear=ramsvm_linear(x,y,k,gamma,weight,lambda,kernel,large,epsilon,warm,nb.core),
	polynomial=ramsvm_kernel(x,y,k,gamma,weight,lambda,kernel,kparam,large,epsilon,warm,nb.core),
	gaussian=ramsvm_kernel(x,y,k,gamma,weight,lambda,kernel,kparam,large,epsilon,warm,nb.core)
			)

	fit$call = this.call
	class(fit) = "ramsvm" 
	return(fit)
}
